-----------------------------------------------------------------------------------------------
-- Client Lua Script for ConfirmItemRewardDialog
-- Created by Caleb. All rights reserved
-----------------------------------------------------------------------------------------------
require "Window"
require "DialogSys"
require "CColor"

local CColor = CColor
local Apollo = Apollo
local DialogSys = DialogSys
local String_GetWeaselString = String_GetWeaselString
local setmetatable = setmetatable
local pairs = pairs
local ipairs = ipairs

local ConfirmItemRewardDialog = {}
local addon = ConfirmItemRewardDialog
local Dialog
local kcrDefaultOptionColor = ApolloColor.new("white")
local kcrHighlightOptionColor = ApolloColor.new(110/255, 255/255, 72/255, 1.0)
function addon:new(o)
	o = o or {}
	setmetatable(o, self)
	self.__index = self
	return o
end

function addon:Init()
	Apollo.RegisterAddon(self)
end

---------------------------------------------------------------------------------------------------
-- EventHandlers
---------------------------------------------------------------------------------------------------
function addon:OnLoad()
	Apollo.CreateTimer("getDialog", 0.1, false)
	Apollo.StartTimer("getDialog")
	Apollo.RegisterTimerHandler("getDialog", "GetDialog", self)
end

---------------------------------------------------------------------------------------------------
-- New Player Bubble Methods
---------------------------------------------------------------------------------------------------

function addon:GetDialog()
	local info = Apollo.GetAddonInfo("Dialog")
	if info and info.bRunning == 1 then
		Apollo.StopTimer("getDialog")

		Dialog = Apollo.GetAddon("Dialog")
		Dialog.wndConfirm = Apollo.LoadForm("ConfirmItemRewardDialog.xml", "ConfirmPopUp", nil, Dialog)
		Dialog.wndConfirm:Show(false)

		function Dialog:OnDialog_Close()
			self.wndPlayer:Show(false)
			self.wndItem:Show(false)
			self.wndNpc:Show(false)
			self.wndConfirm:Show(false)
		end

		function Dialog:OnResponseBtnClick(wndHandler, wndControl)
			if wndHandler and wndHandler:GetData() then
				local drResponse = wndHandler:GetData()
				if drResponse:GetRewardId() and drResponse:GetRewardId() ~= 0 and drResponse:GetRewardId() ~= self.bRewardPicked then
					-- Reset text first
					for idx, wndCurr in pairs(Dialog.wndPlayer:FindChild("ResponseItemContainer"):GetChildren()) do
						if wndCurr:FindChild("ResponseItemText") and wndCurr:FindChild("ResponseItemText"):GetData() then
							wndCurr:FindChild("ResponseItemText"):SetText(wndCurr:FindChild("ResponseItemText"):GetData())
							wndCurr:FindChild("ResponseItemText"):SetTextColor(kcrDefaultOptionColor)
						end
					end
					self.bRewardPicked = drResponse:GetRewardId()
					wndHandler:FindChild("ResponseItemText"):SetText(String_GetWeaselString(Apollo.GetString("Dialog_TakeItem"), wndHandler:FindChild("ResponseItemText"):GetData()))
					wndHandler:FindChild("ResponseItemText"):SetTextColor(kcrHighlightOptionColor)
					self.wndConfirm:Show(true)
					self.wndConfirm:FindChild("ResponseItemText"):SetText(wndHandler:GetData():GetText())
					self.wndConfirm:FindChild("ResponseItemText"):SetTextColor(CColor.new(1, 1, 1, 1))
					local tChoiceRewardData = DialogSys.GetViewableQuest(wndHandler:GetData():GetQuestId()):GetRewardData().arRewardChoices
					local tFoundRewardData
					for idx, tCurrReward in ipairs(tChoiceRewardData) do
						if tCurrReward.idReward == wndHandler:GetData():GetRewardId() then
							tFoundRewardData = tCurrReward
							break
						end
					end
					local strIcon = tFoundRewardData.itemReward:GetIcon()
					Dialog:HelperBuildItemTooltip(self.wndConfirm:FindChild("ResponseItemIcon"), tFoundRewardData.itemReward)
					self.wndConfirm:FindChild("ResponseItemIcon"):SetSprite(strIcon)
					self.wndConfirm:FindChild("YesBtn"):SetData(wndHandler:GetData()) -- tCurrResponse:Select() to fire it later
				elseif drResponse:GetRewardId() and drResponse:GetRewardId() == self.bRewardPicked then
					-- do nothing, because this would accept the reward from the default dialog
				else
					wndHandler:GetData():Select() -- All the work is done in DialogSys's Select Method
				end
			end
		end

		function Dialog:OnConfirmBtnClick(wndHandler, wndControl)
			if wndHandler then
				if wndHandler:GetName() == "YesBtn" then
					wndHandler:GetData():Select()
				end
				self.bRewardPicked = nil
				wndHandler:GetParent():Close()
			end
		end
	end
end

---------------------------------------------------------------------------------------------------
-- instance
---------------------------------------------------------------------------------------------------
local ConfirmItemRewardDialogInst = addon:new()
ConfirmItemRewardDialogInst:Init()
